IntList<T extends num> extension

on

Properties

average num

Available on Iterable<T>, provided by the IntList extension

Calculates the average of all elements in the list.
no setter
max → T

Available on Iterable<T>, provided by the IntList extension

Returns the maximum value in the list.
no setter
median num

Available on Iterable<T>, provided by the IntList extension

Calculates the median of all elements in the list.
no setter
min → T

Available on Iterable<T>, provided by the IntList extension

Returns the minimum value in the list.
no setter
prod num

Available on Iterable<T>, provided by the IntList extension

Returns the product of all elements in the list.
no setter
sum num

Available on Iterable<T>, provided by the IntList extension

Calculates the sum of all elements in the list.
no setter